package com.usky.dxtop.controller.web.business;


import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.utils.DateUtils;
import com.usky.dxtop.model.DreMenu;
import com.usky.dxtop.service.DreMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.context.request.WebRequest;
import org.springframework.web.multipart.MultipartFile;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * 餐品信息
 * @author yq
 * @since 2022-08-14
 */
@RestController
@RequestMapping("/dreMenu")
public class DreMenuController {


    @Autowired
    private DreMenuService dreMenuService;


    /**
     * 上传餐品
     * @param file
     * @return
     */
    @RepeatSubmit
    @PostMapping("/batchByFile")
    public ApiResult<Void> batchByFile(@RequestParam("file") MultipartFile file){
        dreMenuService.addBatchByFile(file);
        return ApiResult.success();
    }

    /**
     * 修改记录
     */
    @PutMapping
    public ApiResult<Void> edit(@RequestBody DreMenu dreMenu) {
        dreMenuService.updateById(dreMenu);
        return ApiResult.success();
    }


    /**
     * 记录查询
     * @param current 页数
     * @param size 条数
     * @param type 餐别
     * @param name 名称
     * @param isRecommend 0不推荐1推荐
     * @param status 0上架1下架
     * @return
     */
    @GetMapping("/list")
    public ApiResult<CommonPage<DreMenu>> list(@RequestParam Integer current,
                                               @RequestParam Integer size,
                                               @RequestParam(required = false) String type,
                                               @RequestParam(required = false) String name,
                                               @RequestParam(required = false) Integer isRecommend,
                                               @RequestParam(required = false) Integer status)
    {

        return ApiResult.success(dreMenuService.page(current,size,type,name,isRecommend,status,null,null));
    }



    @GetMapping("/mDate")
    public ApiResult<String> mDate()
    {
        return ApiResult.success(DateUtils.format(new Date(),null));
    }

    @InitBinder
    public void initBinder(WebDataBinder binder, WebRequest request) {
        //转换日期 注意这里的转化要和传进来的字符串的格式一直 如2015-9-9 就应该为yyyy-MM-dd
        DateFormat dateFormat=new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        binder.registerCustomEditor(Date.class, new CustomDateEditor(dateFormat, true));// CustomDateEditor为自定义日期编辑器
    }



}

