package com.usky.dxtop.controller.web.business;


import com.usky.dxtop.common.core.redis.RedisCache;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.http.HttpUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

/**
 * @author yq
 * @date 2021/6/16 18:02
 */
@RestController
@RequestMapping("aliWeather")
public class WeatherControllerWeb {


    private static final String ALI_WEATHER_API_URL = "https://weather01.market.alicloudapi.com/area-to-weather";
    private static final String ALI_WEATHER_HEADER_KEY = "Authorization";
    private static final String ALI_WEATHER_APPCODE = "0f2b7fce6e104ba8835358b7b59b4fb6";
    private static final String ALI_WEATHER_HEADER_VALUE = "APPCODE " + ALI_WEATHER_APPCODE;


    @Autowired
    private RedisCache redisCache;

    @GetMapping()
    public String get(@RequestParam String area) {
        Object cacheObject = redisCache.getCacheObject(area);
        if (Objects.nonNull(cacheObject)){
            return cacheObject.toString();
        }else {
            String weatherApi = getWeatherApi(area);
            redisCache.setCacheObject(area,weatherApi,30, TimeUnit.MINUTES);
            return weatherApi;
        }
    }
    public String getWeatherApi(String area){
        try {
            Map<String,String> headerMap = new HashMap<>();
            headerMap.put(ALI_WEATHER_HEADER_KEY,ALI_WEATHER_HEADER_VALUE);
            String encode = URLEncoder.encode(area, "UTF-8");
            return HttpUtils.sendGet(ALI_WEATHER_API_URL,String.format("%s%s","area=",encode),headerMap);
        } catch (Exception e) {
            throw new CustomException(e.getMessage());
        }
    }
}

